=== modified file 'NEWS'
--- NEWS	2007-12-10 19:12:00 +0000
+++ NEWS	2007-12-11 05:13:36 +0000
@@ -21,6 +21,10 @@
 
    * Fix Makefile rules for doc generation. (Ian Clatworthy, #175207)
 
+   * ``uncommit`` works even when the commit messages of revisions to be
+     removed use characters not supported in the terminal encoding.
+     (Aaron Bentley)
+
   INTERNALS:
 
   API BREAKS:

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2007-12-09 06:35:14 +0000
+++ bzrlib/builtins.py	2007-12-11 05:13:36 +0000
@@ -3579,6 +3579,7 @@
                     Option('force', help='Say yes to all questions.')]
     takes_args = ['location?']
     aliases = []
+    encoding_type = 'replace'
 
     def run(self, location=None,
             dry_run=False, verbose=False,

=== modified file 'bzrlib/tests/blackbox/test_uncommit.py'
--- bzrlib/tests/blackbox/test_uncommit.py	2007-11-01 19:53:57 +0000
+++ bzrlib/tests/blackbox/test_uncommit.py	2007-12-11 05:13:36 +0000
@@ -18,6 +18,7 @@
 
 import os
 
+import bzrlib
 from bzrlib import uncommit, workingtree
 from bzrlib.bzrdir import BzrDirMetaFormat1
 from bzrlib.errors import BzrError, BoundBranchOutOfDate
@@ -227,3 +228,14 @@
         out, err = self.run_bzr('uncommit --force -r 2')
 
         self.assertEqual(['a2', 'b3', 'c3', 'c4', 'b4'], wt.get_parent_ids())
+
+    def test_uncommit_nonascii(self):
+        tree = self.make_branch_and_tree('tree')
+        tree.commit(u'\u1234 message')
+        real_encoding = bzrlib.user_encoding
+        bzrlib.user_encoding = 'ascii'
+        try:
+            out, err = self.run_bzr('uncommit --force tree')
+        finally:
+            bzrlib.user_encoding = real_encoding
+        self.assertContainsRe(out, r'\? message')

